gparted r947 - in trunk: . src



Author: gedakc
Date: Fri Oct 31 17:15:01 2008
New Revision: 947
URL: http://svn.gnome.org/viewvc/gparted?rev=947&view=rev

Log:
Changed thread status messages to be unique

Modified:
   trunk/ChangeLog
   trunk/src/GParted_Core.cc

Modified: trunk/src/GParted_Core.cc
==============================================================================
--- trunk/src/GParted_Core.cc	(original)
+++ trunk/src/GParted_Core.cc	Fri Oct 31 17:15:01 2008
@@ -239,8 +239,8 @@
 			char * buf = static_cast<char *>( malloc( lp_device ->sector_size ) ) ;
 			if ( buf )
 			{
-				/*TO TRANSLATORS: looks like Reading /dev/sda */ 
-				set_thread_status_message( String::ucompose ( _("Reading %1"), lp_device ->path ) ) ;
+				/*TO TRANSLATORS: looks like Confirming /dev/sda */ 
+				set_thread_status_message( String::ucompose ( _("Confirming %1"), lp_device ->path ) ) ;
 				if ( ped_device_open( lp_device ) )
 				{
 					if ( ped_device_read( lp_device, buf, 0, 1 ) )
@@ -259,8 +259,8 @@
 
 	for ( unsigned int t = 0 ; t < device_paths .size() ; t++ ) 
 	{
-		/*TO TRANSLATORS: looks like Scanning /dev/sda for partitions*/ 
-		set_thread_status_message( String::ucompose ( _("Scanning %1 for partitions"), device_paths[ t ] ) ) ;
+		/*TO TRANSLATORS: looks like Searching /dev/sda partitions */ 
+		set_thread_status_message( String::ucompose ( _("Searching %1 partitions"), device_paths[ t ] ) ) ;
 		if ( open_device_and_disk( device_paths[ t ], false ) )
 		{
 			temp_device .Reset() ;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]